@@ -23,12 +23,13 @@ from stellar_sdk.operation import (
     PathPaymentStrictReceive,
     PathPaymentStrictSend,
 )
-from stellar_sdk.server import Server
+from stellar_sdk.server_async import ServerAsync
 from stellar_sdk.client.aiohttp_client import AiohttpClient
 
 from polaris import settings
 from polaris.models import Asset, Transaction
 from polaris.utils import getLogger, maybe_make_callback_async
+from polaris.integrations import registered_custody_integration as rci
 
 logger = getLogger(__name__)
 PaymentOpResult = Union[
@@ -39,15 +40,25 @@ PaymentOp = Union[Payment, PathPaymentStrictReceive, PathPaymentStrictSend]
 
 class Command(BaseCommand):
     """
-    Streams transactions for the distribution account of each Asset in the DB.
+    Streams transactions to the :attr:`~polaris.models.Asset.distribution_account`
+    of each :class:`~polaris.models.Asset` in the DB.
+
+    Note that this command assumes Stellar payments are made to one distribution
+    account address per asset. Some third party custody service providers may not
+    use this scheme, in which case the custody integration class should provide
+    an alternative command for detecting incoming Stellar payments.
 
     For every response from the server, attempts to find a matching transaction in
-    the database with `find_matching_payment_op` and updates the transaction's
-    status to `pending_anchor` or `pending_receiver` depending on the protocol.
+    the database and updates the transaction's status to ``pending_anchor`` or
+    ``pending_receiver`` depending on the protocol.
 
-    Then, the ``execute_outgoing_transaction`` process will query for transactions
-    in those statuses and provide the anchor an integration function for executing
-    the payment or withdrawal.
+    Then, the :mod:`~polaris.management.commands.execute_outgoing_transactions` process
+    will query for transactions in those statuses and provide the anchor an integration
+    function for executing the payment or withdrawal.
+
+    **Optional arguments:**
+
+        -h, --help            show this help message and exit
     """
 
     def handle(self, *_args, **_options):  # pragma: no cover
@@ -61,18 +72,19 @@ class Command(BaseCommand):
             raise e
 
     async def watch_transactions(self):  # pragma: no cover
-        assets = await sync_to_async(list)(
-            Asset.objects.exclude(distribution_seed__isnull=True)
-        )
+        assets = await sync_to_async(list)(Asset.objects.all())
         await asyncio.gather(
-            *[self._for_account(asset.distribution_account) for asset in assets]
+            *[
+                self._for_account(rci.get_distribution_account(asset=asset))
+                for asset in assets
+            ]
         )
 
     async def _for_account(self, account: str):
         """
         Stream transactions for the server Stellar address.
         """
-        async with Server(settings.HORIZON_URI, client=AiohttpClient()) as server:
+        async with ServerAsync(settings.HORIZON_URI, client=AiohttpClient()) as server:
             try:
                 # Ensure the distribution account actually exists
                 await server.load_account(account)
@@ -82,6 +94,7 @@ class Command(BaseCommand):
                 raise RuntimeError(
                     "Stellar distribution account does not exist in horizon"
                 )
+
             last_completed_transaction = await sync_to_async(
                 Transaction.objects.filter(
                     Q(kind=Transaction.KIND.withdrawal) | Q(kind=Transaction.KIND.send),
@@ -93,7 +106,7 @@ class Command(BaseCommand):
             )()
 
             cursor = "0"
-            if last_completed_transaction:
+            if last_completed_transaction and last_completed_transaction.paging_token:
                 cursor = last_completed_transaction.paging_token
 
             logger.info(
@@ -205,7 +218,7 @@ class Command(BaseCommand):
             if not op_result:  # not a payment op
                 continue
             maybe_payment_data = cls._check_for_payment_match(
-                op, op_result, transaction.asset
+                op, op_result, transaction.asset, transaction
             )
             if maybe_payment_data:
                 if ops[idx].source:
@@ -233,11 +246,15 @@ class Command(BaseCommand):
 
     @classmethod
     def _check_for_payment_match(
-        cls, operation: PaymentOp, op_result: PaymentOpResult, want_asset: Asset
+        cls,
+        operation: PaymentOp,
+        op_result: PaymentOpResult,
+        want_asset: Asset,
+        transaction: Transaction,
     ) -> Optional[Dict]:
         payment_data = cls._get_payment_values(operation, op_result)
         if (
-            payment_data["destination"] == want_asset.distribution_account
+            payment_data["destination"] == transaction.receiving_anchor_account
             and payment_data["code"] == want_asset.code
             and payment_data["issuer"] == want_asset.issuer
         ):
