@@ -8,7 +8,7 @@ from polaris.models import Transaction
 INFO_PATH = "/sep6/info"
 
 
-def good_info_integration(request, asset, lang):
+def good_info_integration(request, asset, lang, *args, **kwargs):
     """
     From the SEP
     """
@@ -53,10 +53,10 @@ def good_info_integration(request, asset, lang):
 @pytest.mark.django_db
 @patch("polaris.sep6.info.registered_info_func", good_info_integration)
 def test_good_info_response(client, usd_asset_factory):
-    usd_asset_factory(protocols=[Transaction.PROTOCOL.sep6])
+    usd_asset_factory(protocols=[Transaction.PROTOCOL.sep6, "sep38"])
     response = client.get(INFO_PATH)
     content = json.loads(response.content)
-    assert response.status_code == 200
+    assert response.status_code == 200, response.content
     assert content == {
         "deposit": {
             "USD": {
@@ -118,10 +118,66 @@ def test_good_info_response(client, usd_asset_factory):
         "transactions": {"enabled": True, "authentication_required": True},
         "transaction": {"enabled": True, "authentication_required": True},
         "features": {"account_creation": True, "claimable_balances": True},
+        "deposit-exchange": {
+            "USD": {
+                "enabled": True,
+                "authentication_required": True,
+                "min_amount": 0.1,
+                "max_amount": 1000.0,
+                "fee_fixed": 5.0,
+                "fee_percent": 1.0,
+                "fields": {
+                    "email_address": {
+                        "description": "your email address for transaction status updates",
+                        "optional": True,
+                    },
+                    "amount": {"description": "amount in USD that you plan to deposit"},
+                    "type": {
+                        "description": "type of deposit to make",
+                        "choices": ["SEPA", "SWIFT", "cash"],
+                    },
+                },
+            }
+        },
+        "withdraw-exchange": {
+            "USD": {
+                "enabled": True,
+                "authentication_required": True,
+                "min_amount": 0.1,
+                "max_amount": 1000.0,
+                "fee_fixed": 5.0,
+                "fee_percent": 0.0,
+                "types": {
+                    "bank_account": {
+                        "fields": {
+                            "dest": {"description": "your bank account number"},
+                            "dest_extra": {"description": "your routing number"},
+                            "bank_branch": {
+                                "description": "address of your bank branch"
+                            },
+                            "phone_number": {
+                                "description": "your phone number in case there's an issue"
+                            },
+                        }
+                    },
+                    "cash": {
+                        "fields": {
+                            "dest": {
+                                "description": (
+                                    "your email address. Your cashout PIN will be sent here. "
+                                    "If not provided, your account's default email will be used"
+                                ),
+                                "optional": True,
+                            }
+                        }
+                    },
+                },
+            }
+        },
     }
 
 
-def bad_fields_type_integration(request, asset, lang):
+def bad_fields_type_integration(request, asset, lang, *args, **kwargs):
     return {"fields": "not a dict"}
 
 
@@ -131,7 +187,7 @@ def test_bad_fields_type(client, usd_asset_factory):
     server_error(client, usd_asset_factory)
 
 
-def bad_types_type(request, asset, lang):
+def bad_types_type(request, asset, lang, *args, **kwargs):
     return {"types": "not a dict"}
 
 
@@ -141,7 +197,7 @@ def test_bad_types_type(client, usd_asset_factory):
     server_error(client, usd_asset_factory)
 
 
-def bad_nested_fields_no_description(request, asset, lang):
+def bad_nested_fields_no_description(request, asset, lang, *args, **kwargs):
     return {"types": {"cash": {"fields": {"key": {"optional": True}}}}}
 
 
@@ -151,7 +207,7 @@ def test_bad_nested_fields_no_description(client, usd_asset_factory):
     server_error(client, usd_asset_factory)
 
 
-def bad_nested_fields_extra_key(request, asset, lang):
+def bad_nested_fields_extra_key(request, asset, lang, *args, **kwargs):
     return {
         "types": {
             "cash": {
@@ -173,11 +229,11 @@ def server_error(client, usd_asset_factory):
     usd_asset_factory(protocols=[Transaction.PROTOCOL.sep6])
     response = client.get(INFO_PATH)
     content = json.loads(response.content)
-    assert response.status_code == 500
+    assert response.status_code == 500, response.content
     assert content == {"error": "unable to process the request"}
 
 
-def unsupported_lang(request, asset, lang):
+def unsupported_lang(request, asset, lang, *args, **kwargs):
     raise ValueError()
 
 
@@ -187,5 +243,5 @@ def test_unsupported_lang(client, usd_asset_factory):
     usd_asset_factory(protocols=[Transaction.PROTOCOL.sep6])
     response = client.get(INFO_PATH + "?lang=es")
     content = json.loads(response.content)
-    assert response.status_code == 400
+    assert response.status_code == 400, response.content
     assert content == {"error": "unsupported 'lang'"}
