@@ -36,3 +36,6 @@ if "sep-24" in settings.ACTIVE_SEPS:
 
 if "sep-31" in settings.ACTIVE_SEPS:
     urlpatterns.append(path("sep31/", include("polaris.sep31.urls")))
+
+if "sep-38" in settings.ACTIVE_SEPS:
+    urlpatterns.append(path("sep38/", include("polaris.sep38.urls")))
